@@ -35,7 +35,7 @@ if  [ "${D_VERSION:-dmd}" == "gdc" ] ; then
     echo "deactivate(){ echo;}" > ~/dlang/gdc-9/activate
 
 else
-    curl --connect-timeout 5 --max-time 10 --retry 5 --retry-delay 1 --retry-max-time 60 https://dlang.org/install.sh | bash -s "$D_VERSION"
+    . $(curl --connect-timeout 5 --max-time 10 --retry 5 --retry-delay 1 --retry-max-time 60 https://dlang.org/install.sh | bash -s "$D_VERSION" -a)
 fi
 
-./travis-ci.sh
+./scripts/ci/travis.sh
